
pyfrc documentation
===================

pyfrc is a python 3 library designed to make developing python code using WPILib for
FIRST Robotics Competition easier.

This library contains a few primary parts:

* A built-in uploader that will upload your robot code to the robot
* Integration with the py.test testing tool to allow you to easily write unit
  tests for your robot code.
* Simulation and 'robot physics' support
  
.. include:: _sidebar.rst.inc

Indices and tables
~~~~~~~~~~~~~~~~~~

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

